=======
History
=======

0.1.0 (2020-01-02)
------------------

* First release on PyPI.

0.2.0 (2018-02-13)
------------------

* Major feature implementation and documentation
* Static typing
* Testing - 44% coverage


0.2.3 (2020-03-28)
------------------

* Testing up to 75%
* Exogenous variable support
* Extensive docs


0.3.0 (2020-03-28)
------------------

* Parallel and distributed training


0.3.1 (2020-03-28)
------------------

* Testing for all reconciliation methods, line coverage > 80%
